@@ -4,7 +4,8 @@ from termcolor import colored
 
 # Expression Errors
 class SyntaxError(Exception):
-    pass
+    def __str__(self) -> str:
+        return f'{self.__class__.__name__}: {super().__str__()}'
 
 
 class TokenizationError(SyntaxError):
@@ -37,6 +38,10 @@ class TreeError(Exception):
     pass
 
 
+class RegistrationWarning(Warning):
+    pass
+
+
 class RegistrationError(Exception):
     pass
 
