@@ -6,16 +6,23 @@ class Operand(Node):
     def __init__(self,
                  value: Union[int, float],
                  precision: int = 3,
-                 symbol: Optional[str]=None,
+                 symbol: Optional[str] = None,
                  **kwargs):
         super().__init__(value=value, **kwargs)
-        self.symbol: str = str(value) if symbol is None else symbol
+        self.precision: int = precision
+        self.symbol: str = symbol if symbol is not None else self.__str__()
+        self.inner_width = len(self.symbol)
         self.width = len(self.symbol)
         self.priority = 20
-        self.precision: int = precision
 
-    def __str__(self):
-        return f'{self.symbol:^{self.width}.{self.precision}}' if type(self.value) is float else f'{self.symbol:^{self.width}}'
+    def __str__(self) -> str:
+        if type(self.value) is int or len(str(self.value).split('.')[1]) <= self.precision:
+            return f'{self.value:^{self.width}}'
+        else:
+            return f'{self.value:^{self.width}.{self.precision}f}'
+
+    def display(self) -> str:
+        return self.symbol
 
     def __repr__(self) -> str:
         return f'Operand({self.value})'
