@@ -1,6 +1,7 @@
 from typing import Callable, List, Literal, Union
 from .exceptions import ReduceTreeError
 from .node import Node
+from math import ceil
 
 
 class Operator(Node):
@@ -19,13 +20,26 @@ class Operator(Node):
         self.operands = operands
         self.func = func
         self.width = len(symbol)
+        self.inner_width = len(symbol)
 
     def __call__(self) -> Union[int, float]:
         if self.children is None:
             raise ReduceTreeError('Tree is not complete')
         return self.func(*map(lambda op: op.value, self.children))
 
-    def __str__(self):
+    def __str__(self) -> str:
+        return self.symbol
+
+    def display(self):
+        if len(self.symbol) <= (self.width - abs(self.bal_coef)):
+            if self.bal_coef > 0:
+                return f'{self.symbol:^{self.width - abs(self.bal_coef)}}' + ' ' * abs(self.bal_coef)
+            else:
+                return ' ' * abs(self.bal_coef) + f'{self.symbol:^{self.width - abs(self.bal_coef)}}'
+        elif self.bal_coef > 0:
+            return f'{self.symbol:<{self.width}}'
+        elif self.bal_coef < 0:
+            return f'{self.symbol:>{self.width}}'
         return f'{self.symbol:^{self.width}}'
 
     def __repr__(self) -> str:
@@ -33,3 +47,6 @@ class Operator(Node):
 
     def isFull(self) -> bool:
         return len(self.children) == self.operands
+
+    # def copy(self):
+    #     return Operator(symbol=self.symbol, fun)
